<?php

require_once 'base/GpepessoaEntityBase.php';

use \Setforms2\Runtime\Connection;

/**
 * Enter description here ...
 *
 * @package Entity
 *
 * @author  alessandrobartels
 *
 */
class GpepessoaEntity extends GpePessoaEntityBase
{

    private $_nrOrg;
    private $_mesCompetencia;
    private $_historicos;
    public $historico;

    /**
     * Construtor.
     *
     * @param integer $id             Identificador.
     * @param integer $nrOrg          Numero da Org. de Trabalho.
     * @param TkDateTime $mesCompetencia Mes de competencia.
     */
    public function __construct($id = null, $nrOrg = null, $mesCompetencia = null)
    {

        parent::__construct($id);

        $this->_nrOrg = $nrOrg;
        $this->_mesCompetencia = $mesCompetencia;
    }


    /**
     * Enter description here ...
     *
     * @param integer $nrOrg    Numero da Org. de Trabalho.
     * @param integer $nrPessoa Numero da Pessoa.
     *
     * @return Ambigous <NULL, mixed>
     */
    public function retornaPessoa($nrOrg, $nrPessoa)
    {
        $pessoa = Gpepessoa::retornaPessoa($nrOrg, $nrPessoa);
        return $pessoa;
    }


    /**
     * Retorna Pessoa com historico atual.
     *
     * @param integer $nrPessoa Numero da Pessoa.
     *
     * @return GpepessoaEntity
     *
     * @author alessandrobartels - 26/12/2011
     */
    public function retornaPessoaAtual($nrPessoa)
    {
        $pessoa = Gpepessoa::retornaPessoaAtual($this->_nrOrg, $this->_mesCompetencia, $nrPessoa);
        return $pessoa;
    }


    /**
     * Retorna Pessoa pelo Parceiro de Negocio.
     *
     * @param integer $nrorg          Numero da Organizacao.
     * @param integer $nr_parcnegocio Numero Parceiro de Negocios.
     *
     * @return GpepessoaEntity
     *
     * @author brunofeliciano -
     */
    public function retornaPessoaPorParceiro($nrorg, $nr_parcnegocio)
    {
        return Gpepessoa::retornaPessoaPorParceiro($nrorg, $nr_parcnegocio);
    }


    /**
     * Enter description here ...
     *
     * @param integer $nrparcnegocio Numero Parceiro de Negocios.
     *
     * @return boolean
     */
    public function incluiPessoa($nrparcnegocio, $nrorg = null)
    {

        if ($nrorg != null) {
            $this->_nrOrg = $nrorg;
        }

        try {
            $pessoa = new self();

            $pessoa->setNrorg($this->_nrOrg);
            $pessoa->setNrparcnegocio($nrparcnegocio);

            $pessoa->persist();

            $nrPessoa = $pessoa->getNrpessoa();
            unset($pessoa);
            return $nrPessoa;
        } catch (Exception $e) {
            throw new Exception(
                ' Exception ' . $e->getLine() . ' : <br />' . $e->getTrace() . ' - ' . $e->getMessage()
            );
        }
    }

    public function inserePessoa($nrorg, $nrparcnegocio)
    {
        $this->setNrorg($nrorg);
        $this->setNrparcnegocio($nrparcnegocio);
    }

    /**
     * @return mixed
     * @autor jorgefonseca
     */
    public function getHistoricos()
    {
        if (!$this->_historicos) {
            $this->_historicos = self::getEntityByWhere(
                'NRORG = ? AND NRPESSOA = ?',
                array($this->getNrorg(), $this->getNrpessoa())
            );
        }
        return $this->_historicos;
    }

    public function beforeInsertPessoa()
    {

        $db = Connection::getInstance()->getConn();
        $query = "SELECT MAX(NRPESSOA) FROM GPE_PESSOA";
        $max = (int)$db->execute($query)->fetchColumn(0);

        $this->setNrpessoa($max + 1);

    }

    public function getPessoa($nrorg, $nrpessoa)
    {
        $params = array(
            'NRORG' => $nrorg,
            'NRPESSOA' => $nrpessoa
        );
        $pessoa = self::getEntityByWhere('NRORG = :NRORG AND NRPESSOA = :NRPESSOA', $params);
        return $pessoa;
    }

    /**
     * @return GpepessoahEntity
     */
    public function getHistoricoCompetencia($mescompetencia)
    {
        $gpepessoah = Gpepessoah::getUltimoHistoricoCompetencia(
            $this->getNrorg(), $this->getNrpessoa(), $mescompetencia
        );

        return $gpepessoah;
    }

    /**
     * @return GpepessoahEntity
     */
    public function getUltimoHistorico()
    {
        if (!$this->historico) {
            $params = array(
                'NRORG' => $this->getNrorg(),
                'NRPESSOA' => $this->getNrpessoa()
            );
            $this->historico = GpepessoahEntity::getEntityByWhere(
                '   NRORG          = :NRORG
                AND NRPESSOA       = :NRPESSOA
                AND DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC)
                                       FROM GPE_PESSOAH
                                      WHERE NRORG    = :NRORG
                                        AND NRPESSOA = :NRPESSOA)',
                $params
            );
        }
        return $this->historico;
    }

}

